﻿using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

using System.Data;
using System.Configuration;
using System.Web.Security;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Telerik.Web.UI;
using System.Collections.Generic;

public partial class Default : System.Web.UI.Page 
{
	private List<DockState> CurrentDockStates
	{
		get
		{
			//Store the info about the added docks in the session. For real life
			// applications we recommend using database or other storage medium
			// for persisting this information.
			List<DockState> _currentDockStates = (List<DockState>)Session["CurrentDockStatesDynamicDocks"];
			if (Object.Equals(_currentDockStates, null))
			{
				_currentDockStates = new List<DockState>();
				Session["CurrentDockStatesDynamicDocks"] = _currentDockStates;
			}
			return _currentDockStates;
		}
		set
		{
			Session["CurrentDockStatesDynamicDocks"] = value;
		}
	}

	private RadDock CreateRadDockFromState(DockState state)
	{
		RadDock dock = new RadDock();
		try
		{
			dock.ID = string.Format("RadDock{0}", state.UniqueName);

			dock.ApplyState(state);
			dock.EnableRoundedCorners = true;

			dock.Command += new DockCommandEventHandler(dock_Command);
			dock.Commands.Add(new DockCloseCommand());
			dock.Commands.Add(new DockExpandCollapseCommand());

			var dockSaveCmd = new DockCommand();
			dockSaveCmd.Name = "SaveToDB";
			dockSaveCmd.Text = "Save";
			dockSaveCmd.CssClass = "sdSaveCmd";
			dockSaveCmd.OnClientCommand = "SaveStopToDB";
			dock.Commands.Add(dockSaveCmd);
		}
		catch (Exception ex)
		{
			return null;
			throw new Exception(ex.Message, ex.InnerException);
		}
		return dock;
	}

	protected void Page_Init(object sender, EventArgs e)
	{
		for (int i = 0; i < CurrentDockStates.Count; i++)
		{
			RadDock dock = CreateRadDockFromState(CurrentDockStates[i]);
			RadDockLayout1.Controls.Add(dock);
			CreateSaveStateTrigger(dock);
			LoadWidget(dock); // the content of the RadDock is loaded

			// The RadDock is removed from the page when closed
			if (CurrentDockStates[i].Closed == true)
			{
				dock.Visible = false;
			}
		}
	}

	private void LoadWidget(RadDock dock) // this method loads the user control in the RadDock
	{
		if (string.IsNullOrEmpty(dock.Tag) || dock.Closed)
		{
			return;
		}
		Control widget = LoadControl("~/Templates/StopFormTplEmpty.ascx");
		widget.EnableViewState = true;
		dock.ContentContainer.Controls.Add(widget);
	}

	private void CreateSaveStateTrigger(RadDock dock)
	{
		dock.AutoPostBack = true;
		dock.CommandsAutoPostBack = true;

		AsyncPostBackTrigger saveStateTrigger = new AsyncPostBackTrigger();
		saveStateTrigger.ControlID = dock.ID;
		saveStateTrigger.EventName = "DockPositionChanged";
		UpdatePanel1.Triggers.Add(saveStateTrigger);

		saveStateTrigger = new AsyncPostBackTrigger();
		saveStateTrigger.ControlID = dock.ID;
		saveStateTrigger.EventName = "Command";
		UpdatePanel1.Triggers.Add(saveStateTrigger);
	}

	void dock_Command(object sender, DockCommandEventArgs e)
	{
		if (e.Command.Name == "SaveToDB")
		{
			var dock = ((RadDock)sender);
			dock.Title = "SaveToDB Command is fired at " + DateTime.Now.ToString();
		}
	}

	protected void RadDockLayout1_LoadDockLayout(object sender, DockLayoutEventArgs e)
	{
		foreach (DockState state in CurrentDockStates)
		{
			e.Positions[state.UniqueName] = state.DockZoneID;
			e.Indices[state.UniqueName] = state.Index;
		}
	}

	protected void RadDockLayout1_SaveDockLayout(object sender, DockLayoutEventArgs e)
	{
		CurrentDockStates = RadDockLayout1.GetRegisteredDocksState();
	}

	protected void RadButtonCreate_Click(object sender, EventArgs e)
	{
		var dock = new RadDock();
		dock.DockMode = DockMode.Docked;
		dock.EnableRoundedCorners = true;
		dock.UniqueName = Guid.NewGuid().ToString();
		dock.ID = string.Format("RadDock{0}", dock.UniqueName);
		dock.Tag = "-1";

		dock.Width = Unit.Percentage(100);
		dock.Height = Unit.Pixel(420);
		dock.Commands.Add(new DockCloseCommand());
		dock.Commands.Add(new DockExpandCollapseCommand());
		var dockSaveCmd = new DockCommand();
		dockSaveCmd.Name = "SaveToDB";
		dockSaveCmd.Text = "Save";
		dockSaveCmd.CssClass = "sdSaveCmd";
		dockSaveCmd.OnClientCommand = "SaveStopToDB";
		dock.Commands.Add(dockSaveCmd);
		dock.CommandsAutoPostBack = true;
		dock.Command += new DockCommandEventHandler(dock_Command);
		RadDockLayout1.Controls.Add(dock); // the new RadDock is added in the RadDockLayout

		dock.Dock(RadDockZoneStops); // the new RadDock is docked in a RadDockZone
		CreateSaveStateTrigger(dock);
		LoadWidget(dock); // the content of the RadDock is loaded
	}

}
